<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:sef="http://www.iss.net/cml/CentralAlerting/securityEventsFilters"
                xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:no="http://www.iss.net/cml/CentralAlerting/no"
                extension-element-prefixes="no">

    <xsl:import href="commonTemplates.xsl"/>

    <xsl:output method='xml' version='1.0' omit-xml-declaration='no' media-type='text/xml' indent='yes'
                encoding='UTF-8'/>
    <xsl:strip-space elements="*"/>
    <xsl:param name="NetworkObjectsAddressListFile"/>
    <xsl:variable name="NetworkObjectsAddressList" select="document($NetworkObjectsAddressListFile)"/>

    <xsl:template match="sef:policy">
        <xsl:element name="RulesDefinition">
            <xsl:apply-templates/>
        </xsl:element>
    </xsl:template>

    <!-- if this is FilterDefinition-->
    <xsl:template match="sef:FilterDefinition">
        <xsl:if test="@enabled = 'true' and count(child::sef:ResponseConfiguration/sef:Responses/child::*) > 0">
            <xsl:element name="FilterDefinition">
                <xsl:attribute name="filterId">
                    <xsl:value-of select="@filterId"/>
                </xsl:attribute>
                <xsl:attribute name="filterName">
                    <xsl:value-of select="@filterName"/>
                </xsl:attribute>
                <xsl:attribute name="ruleThreshold">
                    <xsl:value-of select="@ruleThreshold"/>
                </xsl:attribute>
                <xsl:attribute name="ruleType">event</xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <!-- if this is EventConfiguration-->
    <xsl:template match="sef:EventConfiguration">
        <xsl:for-each select="child::sef:Event">
            <xsl:if test="@enabled = 'true'">
                <xsl:element name="Event">
                    <xsl:attribute name="eventId">
                        <xsl:value-of select="@eventId"/>
                    </xsl:attribute>
                    <xsl:if test="not(child::sef:EventDetail[@eventName = '*'])">
                        <xsl:attribute name="eventName">
                            <xsl:value-of select="child::sef:EventDetail/@eventName"/>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:if test="not(child::sef:EventPriority[@priority = 0])">
                        <xsl:attribute name="priority">
                            <xsl:value-of select="child::sef:EventPriority/@priority"/>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:variable name="eventStatusList">
                        <xsl:for-each select="child::sef:EventStatus">
                            <xsl:value-of select='concat(",", @eventStatusId )'/>
                        </xsl:for-each>
                    </xsl:variable>
                    <xsl:if test="string-length($eventStatusList) > 0">
                        <xsl:attribute name="EventStatus">
                            <xsl:value-of
                                    select="substring($eventStatusList,2, string-length($eventStatusList))"></xsl:value-of>
                        </xsl:attribute>
                    </xsl:if>
                </xsl:element>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>




    <!-- if this is ComponentRuleDefinition-->
    <xsl:template match="sef:ComponentRuleDefinition">
        <xsl:if test="@enabled = 'true' and count(child::sef:ResponseConfiguration/sef:Responses/child::*) > 0">
            <xsl:element name="FilterDefinition">
                <xsl:attribute name="filterId">
                    <xsl:value-of select="@filterId"/>
                </xsl:attribute>
                <xsl:attribute name="filterName">
                    <xsl:value-of select="@filterName"/>
                </xsl:attribute>
                <xsl:attribute name="ruleType">component</xsl:attribute>
                <xsl:if test="child::sefComponentConfiguration/child::sef:ComponentStatusConfiguration">
                    <xsl:attribute name="ruleStrategyType">component</xsl:attribute>
                </xsl:if>
                <xsl:apply-templates select="ComponentConfiguration"/>
                <xsl:apply-templates/>
            </xsl:element>
        </xsl:if>
    </xsl:template>

    <!-- if this is ComponentConfiguration-->
    <xsl:template match="sef:ComponentConfiguration">
        <xsl:choose>
            <xsl:when test="child::sef:ComponentStatusConfiguration">
                <xsl:apply-templates select="child::sef:ComponentStatusConfiguration"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="child::sef:DatabaseStatusConfiguration"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!-- if this is DatabaseStatusConfiguration-->
    <xsl:template match="sef:DatabaseStatusConfiguration">
        <xsl:if test="child::sef:DatabaseAlert[@enabled = 'true']">
            <xsl:attribute name="ruleStrategyType">database</xsl:attribute>
            <xsl:element name="DatabaseSizeThreshold">
                <xsl:attribute name="value">
                    <xsl:value-of select="child::sef:DatabaseAlert/@DatabaseSizeThreshold"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
            <xsl:element name="AVP">
                <xsl:attribute name="value">
                    <xsl:value-of select="child::sef:DatabaseAlert/@DBStatusAvpParameter"/>
                </xsl:attribute>
                <xsl:attribute name="parameter">DBStatusAvpParameter</xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
        </xsl:if>
        <xsl:if test="child::sef:PurgeAlert[@enabled = 'true']">
            <xsl:element name="AVP">
                <xsl:attribute name="value">
                    <xsl:value-of select="child::sef:PurgeAlert/@DBPurgeAvpParameter"/>
                </xsl:attribute>
                <xsl:attribute name="parameter">DBPurgeAvpParameter</xsl:attribute>
                <xsl:apply-templates/>
            </xsl:element>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>

    <!-- if this is ComponentConfiguration-->
    <xsl:template match="sef:ComponentStatusConfiguration">
        <xsl:attribute name="ruleStrategyType">component</xsl:attribute>
        <xsl:variable name="componentStatusList">
            <xsl:for-each select="child::sef:ComponentStatus">
                <xsl:if test="@enabled = 'true'">
                    <xsl:value-of select='concat(",", @componentStatusId )'/>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        <xsl:if test="string-length($componentStatusList) > 0">
            <xsl:element name="AVP">
                <xsl:attribute name="value">
                    <xsl:value-of
                            select="substring($componentStatusList,2, string-length($componentStatusList))"></xsl:value-of>
                </xsl:attribute>
                <xsl:attribute name="parameter">NewStatusID</xsl:attribute>
            </xsl:element>
        </xsl:if>

        <xsl:variable name="componentTypeList">
            <xsl:for-each select="child::sef:ComponentType">
                <xsl:if test="@enabled = 'true'">
                    <xsl:value-of select='concat(",", @componentTypeId )'/>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        <xsl:if test="string-length($componentTypeList) > 0">
            <xsl:element name="AVP">
                <xsl:attribute name="value">
                    <xsl:value-of
                            select="substring($componentTypeList,2, string-length($componentTypeList))"></xsl:value-of>
                </xsl:attribute>
                <xsl:attribute name="parameter">SensorRoleID</xsl:attribute>
            </xsl:element>
        </xsl:if>
        <xsl:apply-templates/>
    </xsl:template>

    <!--if this is ComponentAddressConfiguration-->
       <xsl:template match="sef:ComponentAddressConfiguration">
           <xsl:if test="not(child::sef:ComponentAddress/sef:AnyAddress)">
               <xsl:variable name="ipString">
                   <xsl:call-template name="IPElement">
                     <xsl:with-param name="NetworkObjectsAddressList" select="$NetworkObjectsAddressList"/>
                   </xsl:call-template>
               </xsl:variable>
               <xsl:if test="string-length($ipString) > 0">
                   <xsl:element name="ComponentAddress">
                       <xsl:attribute name="value">
                           <xsl:value-of select="$ipString"/>
                       </xsl:attribute>
                   </xsl:element>
               </xsl:if>
           </xsl:if>
       </xsl:template>
    

    <!-- if this is AVPConfiguration-->
    <xsl:template match="sef:AvpConfiguration">
        <xsl:for-each select="child::sef:AVP">
            <xsl:if test="@enabled = 'true'">
                <xsl:element name="AVP">
                    <xsl:attribute name="value">
                        <xsl:value-of select="@value"/>
                    </xsl:attribute>
                    <xsl:attribute name="parameter">
                        <xsl:value-of select="@parameter"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
        </xsl:for-each>
        <xsl:apply-templates/>
    </xsl:template>


    <!--responses-->
    <xsl:template match="sef:ResponseConfiguration">
        <xsl:element name="Responses">
            <xsl:attribute name="responseThreshold">
                <xsl:value-of select="child::sef:ResponseThreshold/@value"/>
            </xsl:attribute>
            <xsl:if test="count(child::sef:Responses/child::*) > 0">
                <xsl:for-each select="child::sef:Responses/sef:EmailResponse[@enabled = 'true']">
                    <xsl:element name="EmailResponse">
                        <xsl:attribute name="responseId">
                            <xsl:value-of select="@responseId"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:for-each>

                <xsl:for-each select="child::sef:Responses/sef:SnmpResponse[@enabled = 'true']">
                    <xsl:element name="SnmpResponse">
                        <xsl:attribute name="responseId">
                            <xsl:value-of select="@responseId"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:for-each>

                <xsl:for-each select="child::sef:Responses/sef:UserDefinedResponse[@enabled = 'true']">
                    <xsl:element name="UserDefinedResponse">
                        <xsl:attribute name="responseId">
                            <xsl:value-of select="@responseId"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:for-each>

                <xsl:for-each select="child::sef:Responses/sef:PolicyDeploymentResponse[@enabled = 'true']">
                    <xsl:element name="PolicyDeploymentResponse">
                        <xsl:attribute name="id">
                            <xsl:value-of select="@id"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:for-each>
            </xsl:if>
        </xsl:element>
    </xsl:template>

    <!-- if this is SourceConfiguration-->
    <xsl:template match="sef:SourceConfiguration">
        <xsl:if test="child::sef:SourceIP">
            <xsl:apply-templates select="sef:SourceIP"/>
        </xsl:if>
        <xsl:if test="child::sef:SourcePort">
            <xsl:call-template name="sef:SourcePort">
                 <xsl:with-param name="NetworkObjectsAddressList" select="$NetworkObjectsAddressList"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template match="sef:SourceIP">
        <xsl:if test="not(child::sef:AnyAddress)">
            <xsl:variable name="ipString">
                <xsl:call-template name="IPElement">
                     <xsl:with-param name="NetworkObjectsAddressList" select="$NetworkObjectsAddressList"/>
                </xsl:call-template>
            </xsl:variable>
            <xsl:if test="string-length($ipString) > 0">
                <xsl:element name="SourceIP">
                    <xsl:if test="@sourceOp = 'NotFrom'">
                        <xsl:attribute name="sourceOp">
                            <xsl:value-of select="@sourceOp"/>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:attribute name="value">
                        <xsl:value-of select="$ipString"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
        </xsl:if>
    </xsl:template>


    <!-- if this is TargetConfiguration-->
    <xsl:template match="sef:TargetConfiguration">
        <xsl:if test="not(child::sef:TargetIP/sef:AnyAddress)">
            <xsl:variable name="IP1">
                <xsl:call-template name="IPElement">
                     <xsl:with-param name="NetworkObjectsAddressList" select="$NetworkObjectsAddressList"/>
                </xsl:call-template>
            </xsl:variable>
            <xsl:if test="string-length($IP1) > 0">
                <xsl:element name="TargetIP">
                    <xsl:attribute name="value">
                         <xsl:value-of select="$IP1"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
        </xsl:if>
        <xsl:if test="child::sef:TargetPort">
                <xsl:call-template name="sef:TargetPort">
                     <xsl:with-param name="NetworkObjectsAddressList" select="$NetworkObjectsAddressList"/>
                </xsl:call-template>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
